@@ -512,24 +512,54 @@ class BaseConnection(object):
         if ll is not None and len(ll) > 0:
             return ll[0]
 
-    def insert_by_dict(self, row, tablename, check_field_key=False,replace_into=False) -> int:
+    def insert_by_dict(self, row, tablename, check_field_key=False, replace_into=False, ignore_keys=None) -> int:
         """
         通过字典插入数据
         :row
         :tablename
         :check_field_key 是否检查字段是否在表中存在（注意如果不检查可能会被SQL注入）
+        :ignore_keys 忽略的key
         """
+        if ignore_keys is None:
+            ignore_keys = []
+        if check_field_key:
+            columns = self.__select_db_columns(table_name=tablename)
+            cols = [col["COLUMN_NAME"] for col in columns]
+            for key in row.keys():
+                if key not in cols:
+                    raise InsertException(f"{tablename}表不存在Key：{key}的字段")
+        new_rows = {}
+        for k in row.keys():
+            if k not in ignore_keys:
+                new_rows[k] = row[k]
+        if replace_into:
+            sql = f"REPLACE INTO {tablename}({','.join(new_rows.keys())}) VALUES (:{',:'.join(new_rows.keys())})"
+        else:
+            sql = f"INSERT INTO {tablename}({','.join(new_rows.keys())}) VALUES (:{',:'.join(new_rows.keys())})"
+        return self.execute(sql, new_rows)
+
+    def update_by_dict(self, row, tablename, check_field_key=False, ignore_keys=None, where_sql="") -> int:
+        """
+        通过字典更新数据
+        :row
+        :tablename
+        :check_field_key 是否检查字段是否在表中存在（注意如果不检查可能会被SQL注入）
+        """
+        if ignore_keys is None:
+            ignore_keys = []
         if check_field_key:
             columns = self.__select_db_columns(table_name=tablename)
             cols = [col["COLUMN_NAME"] for col in columns]
             for key in row.keys:
                 if key not in cols:
                     raise InsertException(f"{tablename}表不存在Key：{key}的字段")
-        if replace_into:
-            sql = f"REPLACE INTO {tablename}({','.join(row.keys())}) VALUES (:{',:'.join(row.keys())})"
-        else:
-            sql = f"INSERT INTO {tablename}({','.join(row.keys())}) VALUES (:{',:'.join(row.keys())})"
-        return self.execute(sql, row)
+
+        sets = []
+        for k in row.keys():
+            if k not in ignore_keys:
+                sets.append(f"{k}='{row[k]}'")
+        update_sql = f"UPDATE {tablename} SET {','.join(sets)} " + where_sql
+        return self.execute(update_sql, row)
 
     def many_insert_by_dict(self, rows, tablename, replace_into=False):
         """通过字典列表插入数据，请注意方法可能有SQL注入问题"""
